@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Chromatic and diatonic melodic ornamentation
 
-our $VERSION = '0.0300';
+our $VERSION = '0.0400';
 
 use Data::Dumper::Compact qw(ddc);
 use List::SomeUtils qw(first_index);
@@ -47,6 +47,25 @@ sub _build__scale {
     return \@with_octaves;
 }
 
+has _enharmonics => (
+    is        => 'lazy',
+    init_args => undef,
+);
+
+sub _build__enharmonics {
+  my ($self) = @_;
+  my %enharmonics = (
+      'C#' => 'Db',
+      'D#' => 'Eb',
+      'E#' => 'F',
+      'F#' => 'Gb',
+      'G#' => 'Ab',
+      'A#' => 'Bb',
+      'B#' => 'C',
+  );
+  return { %enharmonics, reverse %enharmonics }
+}
+
 
 has verbose => (
     is      => 'ro',
@@ -61,7 +80,7 @@ sub grace_note {
 
     $offset //= 1;
 
-    my $i = first_index { $_ eq $pitch } @{ $self->_scale };
+    (my $i, $pitch) = $self->_find_pitch($pitch);
     my $grace_note = $self->_scale->[ $i + $offset ];
 
     my $x = $MIDI::Simple::Length{$duration} * TICKS;
@@ -84,7 +103,7 @@ sub turn {
     my $number = 4;
     $offset //= 1;
 
-    my $i = first_index { $_ eq $pitch } @{ $self->_scale };
+    (my $i, $pitch) = $self->_find_pitch($pitch);
     my $above = $self->_scale->[ $i + $offset ];
     my $below = $self->_scale->[ $i - $offset ];
 
@@ -106,7 +125,7 @@ sub trill {
     $number ||= 2;
     $offset //= 1;
 
-    my $i = first_index { $_ eq $pitch } @{ $self->_scale };
+    (my $i, $pitch) = $self->_find_pitch($pitch);
     my $alt = $self->_scale->[ $i + $offset ];
 
     my $x = $MIDI::Simple::Length{$duration} * TICKS;
@@ -128,7 +147,7 @@ sub mordent {
     my $number = 4;
     $offset //= 1;
 
-    my $i = first_index { $_ eq $pitch } @{ $self->_scale };
+    (my $i, $pitch) = $self->_find_pitch($pitch);
     my $alt = $self->_scale->[ $i + $offset ];
 
     my $x = $MIDI::Simple::Length{$duration} * TICKS;
@@ -146,6 +165,17 @@ sub mordent {
     return \@mordent;
 }
 
+sub _find_pitch {
+    my ($self, $pitch) = @_;
+    my $i = first_index { $_ eq $pitch } @{ $self->_scale };
+    if ($i == -1) {
+        my $enharmonics = $self->_enharmonics;
+        $pitch =~ s/^([A-G][#b]?)(\d+)$/$enharmonics->{$1}$2/;
+        $i = first_index { $_ eq $pitch } @{ $self->_scale };
+    }
+    return $i, $pitch;
+}
+
 1;
 
 __END__
@@ -160,7 +190,7 @@ Music::MelodicDevice::Ornamentation - Chromatic and diatonic melodic ornamentati
 
 =head1 VERSION
 
-version 0.0300
+version 0.0400
 
 =head1 SYNOPSIS
 
